#!/bin/bash

USERNAME="scs"
MANUFACTURER="SafenSoft"
PRODUCT="scs"
FULLPRODUCTNAME="SoftControl.Server"

ARCHIVE=$FULLPRODUCTNAME.Net.Linux.zip

if [ $# -gt 0 ];
then
  ARCHIVE=$1
fi

if [ ! -f $ARCHIVE ];
then
  echo "Not found SoftControl Server archive - '$ARCHIVE'. Exiting"
  exit 1
fi

if [ ! -d "/opt/$MANUFACTURER/$PRODUCT" ];
then
  echo "Creating directory for SoftControl Server installation"
  sudo mkdir /opt/$MANUFACTURER /opt/$MANUFACTURER/$PRODUCT
fi

if [ ! -d "/usr/share/$MANUFACTURER/$PRODUCT" ];
then
  echo "Creating directory for SoftControl Server config"
  sudo mkdir /usr/share/$MANUFACTURER /usr/share/$MANUFACTURER/$PRODUCT
fi

if cat /etc/passwd | grep -q $USERNAME;
then
  echo "User $USERNAME already exist"
else
  echo "Not found user $USERNAME. Creating..."
  sudo /usr/sbin/useradd --system --home /opt/$MANUFACTURER/$PRODUCT --no-create-home --shell /usr/sbin/nologin --user-group $USERNAME
fi

if [ -f $ARCHIVE ];
then
  echo "Extracting SoftControl Server from archive"
  sudo unzip $ARCHIVE -d /opt/$MANUFACTURER/$PRODUCT
  sudo chown -R $USERNAME:$USERNAME /opt/$MANUFACTURER
else
  echo "Not found SoftControl Server archive - $ARCHIVE. Exiting"
  exit 1
fi

if [ -d "/opt/$MANUFACTURER/$PRODUCT/default_config" ];
then
  echo "Copying default SoftControl Server config into it's config directory"
  sudo cp /opt/$MANUFACTURER/$PRODUCT/default_config/* /usr/share/$MANUFACTURER
  sudo chown -R $USERNAME:$USERNAME /usr/share/$MANUFACTURER
else
  echo "Invalid SoftControl Server archive - default config does not exists. Exiting"
  exit 2
fi

if [ -f "/opt/$MANUFACTURER/$PRODUCT/service/$FULLPRODUCTNAME.service" ];
then
  echo "Add SoftControl Server as SystemD service"
  sudo ln -s -t /etc/systemd/system /opt/$MANUFACTURER/$PRODUCT/service/$FULLPRODUCTNAME.service
else
  echo "Invalid SoftControl Server archive - service definition file does not exists. Exiting"
  exit 3
fi
